==> lxqt-admin_0.16.0.orig.tar.xz: lxqt-admin-0.16.0/lxqt-admin-user/translations/lxqt-admin-user_hu.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hu">
<context>
    <name>GroupDialog</name>
    <message>
        <location filename="../groupdialog.ui" line="14"/>
        <source>Group Settings</source>
        <translation>Csoportbeállítások</translation>
    </message>
    <message>
        <location filename="../groupdialog.ui" line="20"/>
        <source>Group name:</source>
        <translation>Csoportnév:</translation>
    </message>
    <message>
        <location filename="../groupdialog.ui" line="30"/>
        <source>Default</source>
        <translation>Alapértelmezett</translation>
    </message>
    <message>
        <location filename="../groupdialog.ui" line="40"/>
        <source>Group ID:</source>
        <translation>Csoport ID:</translation>
    </message>
    <message>
        <location filename="../groupdialog.ui" line="47"/>
        <source>Users belong to this group:</source>
        <translation>A csoport tagjai:</translation>
    </message>
    <message>
        <location filename="../groupdialog.cpp" line="64"/>
        <source>Error</source>
        <translation>Hiba</translation>
    </message>
    <message>
        <location filename="../groupdialog.cpp" line="64"/>
        <source>The group name cannot be empty.</source>
        <translation>Csoportnév nem lehet üres.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>User and Group Settings</source>
        <translation>Felhasználók és csoportok</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="40"/>
        <source>&amp;Users</source>
        <translation>&amp;Felhasználók</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="59"/>
        <source>Login Name</source>
        <translation>Bejelenkezési név</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="64"/>
        <source>User ID</source>
        <translation>Felhasználó ID</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="69"/>
        <source>Full Name</source>
        <translation>Teljes név</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="74"/>
        <source>Group</source>
        <translation>Csoport</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="79"/>
        <source>Home Directory</source>
        <translation>Saját könyvtár</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="87"/>
        <source>Show system users (for advanced users only)</source>
        <translation>Rendszerfelhasználók is látszanak (csak haladóknak)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="95"/>
        <source>&amp;Groups</source>
        <translation>&amp;Csoportok</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="111"/>
        <source>Name</source>
        <translation>Név</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="116"/>
        <source>Group ID</source>
        <translation>Csoport ID</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="121"/>
        <source>Members</source>
        <translation>Tagok</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="185"/>
        <source>Edit properties of the selected item</source>
        <translation type="unfinished">A kiválasztott elem tulajdonságainak szerkesztése</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="158"/>
        <source>Add</source>
        <translation>Hozzáadás</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="161"/>
        <source>Add new users or groups</source>
        <translation>Új felhasználó, vagy csoport hozzáadása</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="170"/>
        <source>Delete</source>
        <translation>Törlés</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="173"/>
        <source>Delete selected item</source>
        <translation>Kiválasztott elem törlése</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="182"/>
        <source>Properties</source>
        <translation>Tulajdonságok</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="194"/>
        <source>Refresh</source>
        <translation>Frissítés</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="197"/>
        <source>Refresh the lists</source>
        <translation>Lista frissítése</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="206"/>
        <source>Change Password</source>
        <translation>Jelszó módosítása</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="209"/>
        <source>Change password for the selected user or group</source>
        <translation>Felhasználó, vagy csoport jelszavának megváltoztatása</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="177"/>
        <location filename="../mainwindow.cpp" line="189"/>
        <location filename="../mainwindow.cpp" line="210"/>
        <source>Confirm</source>
        <translation>Megerősítés</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="177"/>
        <source>Are you sure you want to delete the selected user?</source>
        <translation>Biztosan törli a kiválasztott felhasználót?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="189"/>
        <source>Are you sure you want to delete the selected group?</source>
        <translation>Biztosan törli a kiválasztott csoportot?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="200"/>
        <source>Input the new password for %1:</source>
        <translation>%1 új jelszava:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="210"/>
        <source>Are you sure you want to set a empty password?</source>
        <translation>Biztos, hogy üres legyen a jelszó?</translation>
    </message>
</context>
<context>
    <name>UserDialog</name>
    <message>
        <location filename="../userdialog.ui" line="14"/>
        <source>User Settings</source>
        <translation>Felhasználó beállítása</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="24"/>
        <source>General</source>
        <translation>Alap</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="43"/>
        <source>Full name:</source>
        <translation>Teljes név:</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="33"/>
        <source>Login name:</source>
        <translation>Bejelenkezési név:</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="53"/>
        <source>User ID:</source>
        <translation>Felhasználó ID:</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="60"/>
        <source>Default</source>
        <translation>Alapértelmezett</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="70"/>
        <source>Main group:</source>
        <translation>Főcsoport:</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="85"/>
        <source>Groups</source>
        <translation>Csoportok</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="91"/>
        <source>The user belongs to the following groups:</source>
        <translation>A felhasználó ezen csoportok tagja:</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="109"/>
        <source>Advanced</source>
        <translation>Haladó</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="115"/>
        <source>Login shell:</source>
        <translation>Parancsértelmező:</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="132"/>
        <source>Home directory:</source>
        <translation>Saját könyvtár:</translation>
    </message>
    <message>
        <location filename="../userdialog.cpp" line="120"/>
        <source>Error</source>
        <translation>Hiba</translation>
    </message>
    <message>
        <location filename="../userdialog.cpp" line="120"/>
        <source>The user name cannot be empty.</source>
        <translation>A felhasználónév nem lehet üres.</translation>
    </message>
</context>
<context>
    <name>UserManager</name>
    <message>
        <location filename="../usermanager.cpp" line="227"/>
        <source>lxqt-admin-user</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../usermanager.cpp" line="228"/>
        <source>&lt;strong&gt;Action (%1) failed:&lt;/strong&gt;&lt;br/&gt;&lt;pre&gt;%2&lt;/pre&gt;</source>
        <translation>&lt;strong&gt;A (%1) művelet sikertelen:&lt;/strong&gt;&lt;br/&gt;&lt;pre&gt;%2&lt;/pre&gt;</translation>
    </message>
</context>
</TS>

==> lxqt-admin_1.1.0.orig.tar.xz: lxqt-admin-1.1.0/lxqt-admin-user/translations/lxqt-admin-user_hu.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="hu">
<context>
    <name>GroupDialog</name>
    <message>
        <location filename="../groupdialog.ui" line="14"/>
        <source>Group Settings</source>
        <translation>Csoportbeállítások</translation>
    </message>
    <message>
        <location filename="../groupdialog.ui" line="20"/>
        <source>Group name:</source>
        <translation>Csoportnév:</translation>
    </message>
    <message>
        <location filename="../groupdialog.ui" line="30"/>
        <source>Default</source>
        <translation>Alapértelmezett</translation>
    </message>
    <message>
        <location filename="../groupdialog.ui" line="40"/>
        <source>Group ID:</source>
        <translation>Csoport ID:</translation>
    </message>
    <message>
        <location filename="../groupdialog.ui" line="47"/>
        <source>Users belong to this group:</source>
        <translation>A csoport tagjai:</translation>
    </message>
    <message>
        <location filename="../groupdialog.cpp" line="64"/>
        <source>Error</source>
        <translation>Hiba</translation>
    </message>
    <message>
        <location filename="../groupdialog.cpp" line="64"/>
        <source>The group name cannot be empty.</source>
        <translation>A csoport neve nem lehet üres.</translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="../mainwindow.ui" line="14"/>
        <source>User and Group Settings</source>
        <translation>Felhasználók és csoportok</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="40"/>
        <source>&amp;Users</source>
        <translation>&amp;Felhasználók</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="59"/>
        <source>Login Name</source>
        <translation>Bejelentkezési név</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="64"/>
        <source>User ID</source>
        <translation>Felhasználó ID</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="69"/>
        <source>Full Name</source>
        <translation>Teljes név</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="74"/>
        <source>Group</source>
        <translation>Csoport</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="79"/>
        <source>Home Directory</source>
        <translation>Saját könyvtár</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="87"/>
        <source>Show system users (for advanced users only)</source>
        <translation>Rendszerfelhasználók megjelenítése (csak haladóknak)</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="95"/>
        <source>&amp;Groups</source>
        <translation>&amp;Csoportok</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="111"/>
        <source>Name</source>
        <translation>Név</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="116"/>
        <source>Group ID</source>
        <translation>Csoport ID</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="121"/>
        <source>Members</source>
        <translation>Tagok</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="185"/>
        <source>Edit properties of the selected item</source>
        <translation>Kiválasztott elem tulajdonságainak szerkesztése</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="158"/>
        <source>Add</source>
        <translation>Hozzáadás</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="161"/>
        <source>Add new users or groups</source>
        <translation>Új felhasználó, vagy csoport hozzáadása</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="170"/>
        <source>Delete</source>
        <translation>Törlés</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="173"/>
        <source>Delete selected item</source>
        <translation>Kiválasztott elem törlése</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="182"/>
        <source>Properties</source>
        <translation>Tulajdonságok</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="194"/>
        <source>Refresh</source>
        <translation>Frissítés</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="197"/>
        <source>Refresh the lists</source>
        <translation>Listák frissítése</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="206"/>
        <source>Change Password</source>
        <translation>Jelszó módosítása</translation>
    </message>
    <message>
        <location filename="../mainwindow.ui" line="209"/>
        <source>Change password for the selected user or group</source>
        <translation>Felhasználó, vagy csoport jelszavának megváltoztatása</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="177"/>
        <location filename="../mainwindow.cpp" line="189"/>
        <location filename="../mainwindow.cpp" line="210"/>
        <source>Confirm</source>
        <translation>Megerősítés</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="177"/>
        <source>Are you sure you want to delete the selected user?</source>
        <translation>Biztosan törli a kiválasztott felhasználót?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="189"/>
        <source>Are you sure you want to delete the selected group?</source>
        <translation>Biztosan törli a kiválasztott csoportot?</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="200"/>
        <source>Input the new password for %1:</source>
        <translation>Adja meg %1 új jelszavát:</translation>
    </message>
    <message>
        <location filename="../mainwindow.cpp" line="210"/>
        <source>Are you sure you want to set a empty password?</source>
        <translation>Biztos benne, hogy üres legyen a jelszó?</translation>
    </message>
</context>
<context>
    <name>UserDialog</name>
    <message>
        <location filename="../userdialog.ui" line="14"/>
        <source>User Settings</source>
        <translation>Felhasználó beállítások</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="24"/>
        <source>General</source>
        <translation>Általános</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="43"/>
        <source>Full name:</source>
        <translation>Teljes név:</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="33"/>
        <source>Login name:</source>
        <translation>Bejelentkezési név:</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="53"/>
        <source>User ID:</source>
        <translation>Felhasználó ID:</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="60"/>
        <source>Default</source>
        <translation>Alapértelmezett</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="70"/>
        <source>Main group:</source>
        <translation>Főcsoport:</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="85"/>
        <source>Groups</source>
        <translation>Csoportok</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="91"/>
        <source>The user belongs to the following groups:</source>
        <translation>A felhasználó ezen csoportok tagja:</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="109"/>
        <source>Advanced</source>
        <translation>Haladó</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="115"/>
        <source>Login shell:</source>
        <translation>Parancsértelmező:</translation>
    </message>
    <message>
        <location filename="../userdialog.ui" line="132"/>
        <source>Home directory:</source>
        <translation>Saját könyvtár:</translation>
    </message>
    <message>
        <location filename="../userdialog.cpp" line="120"/>
        <source>Error</source>
        <translation>Hiba</translation>
    </message>
    <message>
        <location filename="../userdialog.cpp" line="120"/>
        <source>The user name cannot be empty.</source>
        <translation>A felhasználónév nem lehet üres.</translation>
    </message>
</context>
<context>
    <name>UserManager</name>
    <message>
        <location filename="../usermanager.cpp" line="227"/>
        <source>lxqt-admin-user</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../usermanager.cpp" line="228"/>
        <source>&lt;strong&gt;Action (%1) failed:&lt;/strong&gt;&lt;br/&gt;&lt;pre&gt;%2&lt;/pre&gt;</source>
        <translation>&lt;strong&gt;A (%1) művelet sikertelen:&lt;/strong&gt;&lt;br/&gt;&lt;pre&gt;%2&lt;/pre&gt;</translation>
    </message>
</context>
</TS>
